==> estateplat-common-1.2.4-20220302.065644-980-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/DjfDjSfBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.DjfDjSf;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;
import cn.gtmap.estateplat.utils.JaxbStringNoNullAdapter;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;

public class DjfDjSfBdc extends DjfDjSf {
    private String dfsflxdm;
    private String dfsflxmc;
    private String dffffdm;
    private String dffffmc;
    @XmlAttribute(
            name = "DFSFLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsflxdm() {
        return dfsflxdm;
    }

    public void setDfsflxdm(String dfsflxdm) {
        this.dfsflxdm = dfsflxdm;
    }
    @XmlAttribute(
            name = "DFSFLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsflxmc() {
        return dfsflxmc;
    }

    public void setDfsflxmc(String dfsflxmc) {
        this.dfsflxmc = dfsflxmc;
    }
    @XmlAttribute(
            name = "DFFFFDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffffdm() {
        return dffffdm;
    }

    public void setDffffdm(String dffffdm) {
        this.dffffdm = dffffdm;
    }
    @XmlAttribute(
            name = "DFFFFMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffffmc() {
        return dffffmc;
    }

    public void setDffffmc(String dffffmc) {
        this.dffffmc = dffffmc;
    }
}

==> estateplat-common-1.2.4-20241101.091621-1262-sources.jar: cn/gtmap/estateplat/model/exchange/unidofrmity/DjfDjSfBdc.java <==
package cn.gtmap.estateplat.model.exchange.unidofrmity;

import cn.gtmap.estateplat.model.exchange.national.newStandard.DjfDjSfNew;
import cn.gtmap.estateplat.utils.JaxbStringAdapter;

import javax.persistence.Table;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.adapters.XmlJavaTypeAdapter;
@Table(name = "DJF_DJ_SF")
public class DjfDjSfBdc extends DjfDjSfNew {
    private String dfsflxdm;
    private String dfsflxmc;
    private String dffffdm;
    private String dffffmc;
    @XmlAttribute(
            name = "DFSFLXDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsflxdm() {
        return dfsflxdm;
    }

    public void setDfsflxdm(String dfsflxdm) {
        this.dfsflxdm = dfsflxdm;
    }
    @XmlAttribute(
            name = "DFSFLXMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDfsflxmc() {
        return dfsflxmc;
    }

    public void setDfsflxmc(String dfsflxmc) {
        this.dfsflxmc = dfsflxmc;
    }
    @XmlAttribute(
            name = "DFFFFDM"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffffdm() {
        return dffffdm;
    }

    public void setDffffdm(String dffffdm) {
        this.dffffdm = dffffdm;
    }
    @XmlAttribute(
            name = "DFFFFMC"
    )
    @XmlJavaTypeAdapter(JaxbStringAdapter.class)
    public String getDffffmc() {
        return dffffmc;
    }

    public void setDffffmc(String dffffmc) {
        this.dffffmc = dffffmc;
    }
}
